<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nn_NO">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>Jump to PDF</source>
        <translation>Hopp til PDF</translation>
    </message>
    <message>
        <source>No suggestions</source>
        <translation>Ingen forslag</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translation>Ignorer ord</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>Klarte ikkje sletta</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>Kan ikkje sletta alle tilleggsfilene. Kontroller om du har skriveløyve til dei.</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translation>Stadfest sletting</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>Tilleggsfiler som skal slettast:</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Merk alle</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation>Merk ingen</translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation>På/av</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>Finn</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Finn:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Søk rundt</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Finn &amp;bakover</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>Søk i &amp;merkt tekst</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Vis &amp;alle søkjetreffa</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>Søk i alle &amp;opne filer</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Skil mellom store og små bokstavar</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>Berre &amp;heile ord</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>&amp;Regulært uttrykk</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Ingen gamle søk</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(ugyldig)</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>Bryt linjer</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>Bryt linjer ved:</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>Gjeldande vindaugsstorleik</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>Linjelengd:</translation>
    </message>
    <message>
        <source>Unwrap</source>
        <translation>Fjern linjeskift</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>Bryt avsnitt på nytt</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>Nyleg brukt</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>Klarte ikkje opna fila«%1». Kontroller at ho er ei gyldig PDF-fil.</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>Ingen SyncTex-data tilgjengeleg</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation>SyncTeX: «%1»</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] – %2</translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>side %1 av %2</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1 %</translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation>namnlaus.pdf[*]</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Vindauge</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Kompiler</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Verktøylinje</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>Om Texworks …</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>Første side</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Førre side</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Neste side</translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>Siste side</translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>Gå til side …</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Vis større</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Vis mindre</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Tilpass til vindauge</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>Verkeleg storleik</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Tilpass til sidebreidd</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Opna …</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Angra</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Gjer om</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klipp ut</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Tøm</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation>Ctrl+Backspace</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Innstillingar …</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stabel</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Jamsides</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translation>Gå til kjedefila</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Ny frå mal …</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>Fullskjerm</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation>Ctrl+Shift+F</translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>Forstørr</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Rull</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>Merk tekst</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Vel bilete</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Gå til TeXworks-heimesida</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Melding til e-postlista</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Side ved side</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Plasser til venstre</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Plasser til høgre</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Avslutt TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Finn på nytt</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Kompiler</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Skript</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>Skripting av TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgUp</translation>
    </message>
    <message>
        <source>Ctrl+PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation>Ctrl+PgDown</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Finn …</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>Oppdater skriptliste</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Handter skript</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>Vis skriptmappe</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>Om skript …</translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation>Skriv ut PDF …</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>Innstillingar og ressursar …</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Tøm nyleg brukte filer</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>Avbryt kompilering</translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation>Av ulike tekniske grunnar kan dessverre ikkje denne versjonen av %1 skriva ut PDF-dokument.
</translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation>Vil du opna fila i standard PDF-lesar og skriva ho ut derifrå i staden for?</translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translatorcomment>Skal vera stor forbokstav og punktum her, sidan det vert vist som sjølvstendig setning.
</translatorcomment>
        <translation> (Hugs å lukka programmet igjen etterpå, for å unngå tilgangsproblem.)</translation>
    </message>
    <message>
        <source>Error initializing SyncTeX</source>
        <translation>Feil ved start av SyncTeX</translation>
    </message>
    <message>
        <source>Go to previous view</source>
        <translation>Gå til førre vising</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation>Alt + Pil venstre</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>Éi side</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>Éi side – samanhengande</translation>
    </message>
    <message>
        <source>Two Pages Continuous</source>
        <translation>To sider – samanhengande</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>Hopp til kjeldefil</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation>Gå til side</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>Sidetal:</translation>
    </message>
    <message>
        <source>Open URL</source>
        <oldsource>Open URL</oldsource>
        <translation>Opna adresse</translation>
    </message>
    <message>
        <source>You are in the process of opening the URL %1. Opening unknown or untrusted web adresses can be a security risk.
Do you want to continue?</source>
        <translation>Du er i ferd med å opna adressa %1. Å opna ukjende nettadresser er ein tryggleiksrisiko.
Er du sikker på at du vil halda fram?</translation>
    </message>
    <message>
        <source>Custom...</source>
        <oldsource>Custom...</oldsource>
        <translation>Tilpassa …</translation>
    </message>
    <message>
        <source>Set Zoom</source>
        <oldsource>Set Zoom...</oldsource>
        <translation>Vel visingsstorleik</translation>
    </message>
    <message>
        <source>Zoom level:</source>
        <oldsource>Log level:</oldsource>
        <translation>Forstørring:</translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>Finn</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Ingen gamle søk</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>Finn i PDF</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Finn:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Søk rundt</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Finn &amp;bakover</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>Finn &amp;alle tilfella</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Skil mellom store og små bokstavar</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translation>&amp;Synkroniser med kjeldefil</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>Vel mappe</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>Nytt verktøy</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>Systemstandard (%1)</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>TeXworks-innstillingar</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>Små ikon</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>Mellomstore ikon</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>Store ikon</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>Vis også knapptekst</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>Vis ved oppstart</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>Nytt, tomt dokument</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>Val av mal</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>Filopningsvindauge</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Skriveprogram</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>Standard for skriveprogram</translation>
    </message>
    <message>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>Tabulatorbreidd:</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>Bryt linjer</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>Fargelegging:</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>Automatiske innrykk:</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>Språk for stavekontroll:</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>Teiknkoding:</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Førehandsvising</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>Standardforstørring</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>Verkeleg storleik</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>Tilpass til sidebreidd</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>Tilpass til vindauge</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>Fast skalering:</translation>
    </message>
    <message>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>Forstørringsglas</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Liten</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Middels</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Stor</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>Sirkelforma forstørring</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>Skjermoppløysing:</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>Kompilering</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>Mapper til programfiler for TeX og nærskylde program</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>Handsamingsverktøy</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Rediger …</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>Standard:</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Grensesnitt</translation>
    </message>
    <message>
        <source>Locale:</source>
        <translation>Språk:</translation>
    </message>
    <message>
        <source>Toolbar buttons:</source>
        <translation>Verktøylinjeknappar:</translation>
    </message>
    <message>
        <source>Open corresponding PDF preview with TeX files</source>
        <translation>Med TeX-filer, opna tilhøyrande PDF-fil</translation>
    </message>
    <message>
        <source> px</source>
        <translation> pikslar</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>Linjenummer</translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translation>Automatiske hermeteikn:</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>Globale redigeringsval</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>Marker gjeldande linje</translation>
    </message>
    <message>
        <source>Enable autocompletion</source>
        <translation>Bruk autofullføring</translation>
    </message>
    <message>
        <source>&lt;em&gt;Note:&lt;/em&gt; These are default settings. Changes to them will not affect windows that are already open. Use the respective items in the &amp;quot;Format&amp;quot; menu to achieve that.</source>
        <translation>&lt;em&gt;Merk:&lt;/em&gt; Dette er standardinnstillingane. Endringar her vil ikkje påverka allereie opne vindauge. Bruk «Format»-menyen for desse.</translation>
    </message>
    <message>
        <source>Hide console output:</source>
        <translation>Gøym resultatpanel:</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;strong&gt;Never:&lt;/strong&gt; Never hide the console output panel after typesetting.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Automatically:&lt;/strong&gt; Hide the console output panel after successful typesetting, but only if it was hidden before.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;On Success:&lt;/strong&gt; Hide the console output panel after successful typesetting, regardless of its previous state.&lt;/p&gt;
</source>
        <translation>&lt;p&gt;&lt;strong&gt;Alder:&lt;/strong&gt; Gøym aldri resultatpanelet etter kompilering.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Automatisk:&lt;/strong&gt; Gøym resultatetpanelet etter vellukka kompilering, men berre om det var gøymt frå før.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Om vellukka:&lt;/strong&gt; Gøym alltid resultatetpanelet etter vellukka kompilering.&lt;/p&gt;
</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>Aldri</translation>
    </message>
    <message>
        <source>Automatically</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>On success</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>Om vellukka</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Skript</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Tryggleik</translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation>Tillat at skript les alle filer (skript og dokumentfiler eller alltid lesbare)</translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation>Tillat at skript lagrar filer</translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation>Tillat at skript køyrer systemkommandoar</translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation>Tillat tilleggsskriptspråk (desse kan omgå andre avgrensingar på skriptatferd)</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>Feilsøking</translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation>Bruk QtScript-feilsøkjaren</translation>
    </message>
    <message>
        <source>Page mode:</source>
        <translation>Sidemodus:</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>Éi side</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>Éi side – samanhengande</translation>
    </message>
    <message>
        <source>Two Page Continuous</source>
        <translation>To sider – samanhengande</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>TeX-dokument (*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>LaTeX-dokument (*.ltx)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>BibTeX-databasar (*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>Stilfiler (*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>Klassefiler (*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>Makroar med dokumentasjon (*.dtx)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Tekstfiler (*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>PDF-dokument (*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <source>Log files (*.log *.blg)</source>
        <translation>Loggfiler (*.log *.blg)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</source>
        <translation>Tilleggsfiler (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation>Byt ut</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>Byt ut alle</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>Ingen gamle søk</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>Ingen gamle utbytingstekstar</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(ugyldig)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>Byt ut:</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>Med:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>&amp;Søk rundt</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>Finn &amp;bakover</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>Byt ut i &amp;merkt område</translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>Byt ut i alle &amp;opne filer</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>&amp;Skil mellom store og små bokstavar</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>Berre &amp;heile ord</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>&amp;Regulært uttrykk</translation>
    </message>
</context>
<context>
    <name>ResourcesDialog</name>
    <message>
        <source>TeXworks Settings and Resources</source>
        <translation>Innstillingar og ressursar for TeXworks</translation>
    </message>
    <message>
        <source>Storage Locations</source>
        <translation>Lagringsområde</translation>
    </message>
    <message>
        <source>Settings:</source>
        <translation>Innstillingar:</translation>
    </message>
    <message>
        <source>Resources:</source>
        <translation>Ressursar:</translation>
    </message>
    <message>
        <source>Registry (%1)</source>
        <translation>Register (%1)</translation>
    </message>
</context>
<context>
    <name>ScreenCalibrationWidget</name>
    <message>
        <source>Drag the ruler or change the value to match real world lengths.
Common paper sizes are marked as well (you may need to resize the dialog window to see them).
Use the context menu to change the units.</source>
        <translation>Dra linjalen eller endra verdien slik at han svarer til fysisk lengd.
Vanlege papirstorleikar er òg merkerte. (Det kan vera du må endra storleiken på vindauget for å sjå dei).
Bruk kontekstmenyen for å endra einingane.</translation>
    </message>
    <message>
        <source> dpi</source>
        <extracomment>dots per inch</extracomment>
        <translation> p.p.t.</translation>
    </message>
    <message>
        <source>DIN A4</source>
        <translation>A4</translation>
    </message>
    <message>
        <source>Letter</source>
        <oldsource>Letter</oldsource>
        <translation>Letter</translation>
    </message>
    <message>
        <source>cm</source>
        <oldsource>cm</oldsource>
        <extracomment>this refers to the length unit of centimeters</extracomment>
        <translation>cm</translation>
    </message>
    <message>
        <source>in</source>
        <oldsource>in</oldsource>
        <extracomment>this refers to the length unit of inches</extracomment>
        <translation>tommar</translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Manage Scripts</source>
        <translation>Handter skript</translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation>Frittståande skript</translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation>Krokskript</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Namn: </translation>
    </message>
    <message>
        <source>Context: </source>
        <translation>Samanheng: </translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Skildring: </translation>
    </message>
    <message>
        <source>Author: </source>
        <translation>Forfattar: </translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>Versjon: </translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation>Snøggtast: </translation>
    </message>
    <message>
        <source>File: </source>
        <translation>Fil: </translation>
    </message>
    <message>
        <source>Language: </source>
        <translation>Språk: </translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation>Krok: </translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>Søkjeresultat</translation>
    </message>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation>Søkjeresultat – %1 (%2 treff)</translation>
    </message>
    <message>
        <source>...</source>
        <translation> ...</translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Ny frå mal …</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Innstillingar …</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Opna …</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Nyleg brukt</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>About </source>
        <translation>Om </translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Gå til TeXworks-heimesida</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Meldings til e-postlista</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1 er eit enkelt program for redigering, kompilering og vising av TeX-dokument.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF-bibliotek av Kristian Høgsberg, Albert Astals Cid og andre.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation>&lt;br&gt;Konsept og ressursar frå &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; av Richard Koch.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt;-teknologi av J&amp;#xE9;r&amp;#xF4;me Laurens.</translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation>&lt;br&gt;Nokre av ikona er tekne frå &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt;Omsetjing til %1 av %2.</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>Norwegian Nynorsk</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>Karl Ove Hufthammer &lt;karl@huftis.org&gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>Fekk ikkje tilgang til «%1». Kontroller at nettlesaren eller e-postprogrammet er rett sett opp.</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>Klarte ikkje oppretta vindauge</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>Noko gjekk skikkeleg gale. %1 klarte ikkje oppretta dokumentvindauget. Programmet vert no avslutta.</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Opna fil</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>Fann inga standardplassering for programfiler</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.&lt;/small&gt;</source>
        <translation>Fann ingen av dei standardplasseringane for TeX-programfiler.&lt;p&gt;&lt;small&gt;For å kunna kompilera filene, må du oppgje adressa/adressene til TeX-distribusjonen din under «Instillingar → Kompilering».&lt;/small&gt;</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Tøm nyleg brukte dokument</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2 or (at your option) any later version.</source>
        <translation>&lt;p&gt;Distribuert under &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, versjon 2 eller (om du ønskjer) ein seinare versjon.</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Lagra fil</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>Fann ikkje hjelpefila.</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation>Tilgangsførespurnad</translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation>Skriptet «%1» prøver å opna fila «%2», men har ikkje løyve til dette. Ønskjer du å opna fila?</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2) [r.%3, %4]</source>
        <translation>&lt;br&gt;Versjon %1 (%2) [r.%3, %4]</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2)</source>
        <translation>&lt;br&gt;Versjon %1 (%2)</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Avslutt TeXworks</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by The Qt Company.</source>
        <translation>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt programvarerammeverk&lt;/a&gt; v%1 av The Qt Company.</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; stavekontroll av L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation>Intern feil</translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation>Klarte ikkje køyra systemkommando: %1</translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation>Feil ved køyring av systemkommando: %1</translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation>Køyring av systemkommandoar er slått av (sjå innstillingane)</translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation>Klarte ikkje opna «%1».</translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation>Lesing av alle filer er slått av (sjå innstillingane)</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation>Klarte ikkje opna fila «%1» for lesing</translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation>Skript «%1»: %2</translation>
    </message>
    <message>
        <source>Script result</source>
        <translation>Skriptresultat</translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation>ukjend feil</translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation>Skript kan brukast til å leggja nye kommandoar til %1 og til å utvida eller endra funksjonalitet.</translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation>Du finn meir informasjon om korleis du lagar og brukar skript på %1.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation>Skriptspråk som kan brukast i denne utgåva av %1:</translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation>Om skript</translation>
    </message>
    <message>
        <source>Script error</source>
        <translation>Skript-feil</translation>
    </message>
    <message>
        <source>(disabled in the preferences)</source>
        <extracomment>This string is appended to a script language name to indicate it is currently disabled</extracomment>
        <translation>(slått av i innstillingane)</translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation>Feil: feilkode %1</translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation>Feil: avsluttingskode %1</translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>Merkelappar</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Bokmerke</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>Disposisjon</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>Ingen merkelappar</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>Nytt dokument</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>Nyleg brukt</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Opna fil</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Lagra fil</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>Dokumentet «%1» er endra.
Vil du lagra endringane?</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>Vil du forkasta alle endringane i dokument «%1» og tilbakestilla til den siste lagra versjonen?</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>Tilbakestill</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>Ukjend teiknkoding</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>Fila er endra på disken</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>Dokumentet «%1» var ikkje lagra</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>Teksten kan ikkje gjerast om</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation>namnlaus-%1.tex</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] – %2</translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>Linje %1 av %2 – kolonne %3</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>Gå til linje</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>Linjenummer:</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>Ugyldig regulært uttrykk</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>Ikkje funnen</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translation>
            <numerusform>Fann %n treff</numerusform>
            <numerusform>Fann %n treff</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n treff</numerusform>
            <numerusform>%n treff</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n dokument</numerusform>
            <numerusform>%n dokument</numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>Bytte ut «%1» med «%2»</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>Bytte ut %n treff</numerusform>
            <numerusform>Bytte ut %n treff</numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>Kan ikkje handsama ulagra dokument</translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>Rotdokumentet %1 kan ikkje lesast</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1 er ikkje rett sett opp</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>Klarte ikkje køyra %1</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>Vel kompileringsmotor til «%1»</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>Kompileringsmotoren «%1» er ikkje definert</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>Fann ikkje nokon filer</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>Fann ingen tilleggsfiler til dette dokumentet.</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation>namnlaus.tex[*]</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>Stavekontroll</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>Byt store og små bokstavar</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>Kompiler</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Vindauge</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>Autoinnrykk</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>Fargelegging</translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>Automatiske hermeteikn</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>Kompileringsverktøylinje</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>Redigeringsverktøylinje</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Opna …</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Lagra</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Lagra som …</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl + Shift + S</translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>Tilbakestill til lagra versjon</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Angra</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Gjer om</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klipp ut</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Tøm</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>Finn …</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>Finn på nytt</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>Byt ut …</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>Kopier til finn</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>Kopier til utbyting</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>Gå til linje …</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>Finn i utval</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Merk alt</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>Skrift …</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>Rykk inn</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation>Ctrl+]</translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>Rykk tilbake</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation>Ctrl+[</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommenter</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation>Ctrl+Shift+]</translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>Fjern kommentering</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation>Ctrl+Shift+[</translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>Bryt linjer</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>Om TeXworks …</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stabel</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>Jamsides</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Innstillingar …</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>Gå til førehandsvising</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation>Ctrl+\</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>Ny frå mal …</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>Vis utval</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>STORE BOKSTAVAR</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>små bokstavar</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>Merk blokk</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>Gå til TeXworks-heimesida</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>Melding til e-postlista</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>Side ved side</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>Plasser til venstre</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>Plasser til høgre</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>Byt ut på nytt</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Shift+R</translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>Slett tilleggsfiler …</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>Avslutt TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Console output</source>
        <translation>Resultatpanel</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>Kompiler</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Skript</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>TeXworks-skript</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Hide Console Output</source>
        <translation>Gøym resultatpanel</translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>Store/små bokstavar</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>Harde linjeskift …</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>Linjenummer</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>Vis skriptmappe</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>Oppdater skriptliste</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>Handter skript</translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation>Automatisk fokus</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>Om skript …</translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation>Bruk på utval</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Lagra alle</translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation>Ctrl+Alt+S</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>Innstillingar og ressursar …</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>Tøm nyleg brukte dokument</translation>
    </message>
    <message>
        <source>Abort typesetting?</source>
        <translation>Vil du avbryta kompileringa?</translation>
    </message>
    <message>
        <source>A typesetting process is still running and must be stopped before closing this window.
Do you want to stop it now?</source>
        <translation>Kompilering pågår, og må avbrytast før du kan lukka dette vindauget.
Ønskjer du å avbryta kompileringa no?</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation>Klarte ikkje lesa fila «%1»:
%2</translation>
    </message>
    <message>
        <source>Layout Problem</source>
        <translation>Visingsproblem</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation>Fila «%1» lasta</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation>Klarte ikkje lagra fila «%1»:
%2</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation>Feil ved skriving til fil</translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation>Det oppstod ein feil ved lagring av fila. Du kan prøva å lagra ho i ei anna mappe.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation>Fila «%1» er lagra</translation>
    </message>
    <message>
        <source>Reload using selected encoding</source>
        <extracomment>Item in the encoding popup menu</extracomment>
        <translation>Last inn att med vald teiknkoding</translation>
    </message>
    <message>
        <source>Unsaved changes</source>
        <translation>Ulagra endringar</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>Fann ikkje programmet «%1».</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; or &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>Du treng ein &lt;b&gt;TeX-distribusjon&lt;/b&gt;, som for eksempel &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; eller &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt;, installert for å kunna kompilera dokument.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>Du treng ein &lt;b&gt;TeX-distribusjon&lt;/b&gt;, som for eksempel &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt;, installert for å kunna kompilera dokument.</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; installed on your system to typeset your document. On most systems such a TeX distribution is available as prebuilt package.</source>
        <translation>Du treng ein &lt;b&gt;TeX-distribusjon&lt;/b&gt;, som for eksempel &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt;, installert for å kunna kompilera dokument. På dei fleste systema finst TeX-distribusjonen som ferdigbygde pakkar.</translation>
    </message>
    <message>
        <source>When a TeX distribution is installed you may need to tell TeXworks where to find it in Edit -&gt; Preferences -&gt; Typesetting.</source>
        <translation>Når ein TeX-distribusjon er installert, kan det vera du må gje TeXworks beskjed om korleis programmet skal finna han, via «Rediger → Instillingar → Kompilering».</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>Søkte i desse mappene:</translation>
    </message>
    <message>
        <source>Check the configuration of the %1 tool and the path settings in the Preferences dialog.</source>
        <translation>Sjå til at oppsettet og filadressene til %1-verktøyet i innstillingane er rette.</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>Avbryt kompilering</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>Prosess avbroten av brukar</translation>
    </message>
    <message>
        <source>Show Console Output</source>
        <translation>Vis resultatpanel</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>Teiknkodinga %1 brukt i %2 er ikkje støtta.

Fila vert derfor lesen med teiknkodinga %3, som kan føra til feil tekst.</translation>
    </message>
    <message>
        <source>A problem occured while laying out the loaded document in the editor. This is caused by an issue in the underlying Qt framework and can cause TeXworks to crash under certain circumstances. The symptoms of this problem are hidden or overlapping lines. To work around this, please try one of the following:
 -) Turn syntax highlighting off and on
 -) Turn line numbers off and on
 -) Resize the window

We are sorry for the inconvenience.</source>
        <translation>Det oppstod eit problem ved vising av dokumentet i skriveprogrammet. Grunnen er ein feil i det underliggjande Qt-rammeverket, og kan føra til at TeXworks i nokre tilfelle krasjar. Symptom på problemet er usynlege eller overlappande linjer. For å unngå problemet, kan du prøva desse løysingane:
– Slå fargelegging av og på att
– Slå linjenummer av og på att
– Endra storleiken på vindauge

Me beklagar dette.</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>%1 er endra av eit anna program.

Ønskjer du å forkasta endringane du har gjort, og lasta inn fila frå disken?</translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation>%1 vert stadig endra av eit anna program.

Bruk «Fil → Tilbakestill til lagra versjon» når programmet er ferdig.</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>%1 er endra av eit anna program.

Ønskjer du likevel å lagra fila, og overskriva versjonen på disken?</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>Dette dokumentet inneheld teikn som ikkje kan representerast i teiknkodinga %1.

Viss du held fram, vert dei bytte ut med standardteikn. Du kan òg velja å bruka ei anna teiknkoding (som UTF-8), for å unngå tap av data.</translation>
    </message>
    <message>
        <source>Reloads the current file with the encoding selected from this menu.

The selected encoding replaces the default one and overrides all &quot;%!TEX encoding&quot; lines.</source>
        <extracomment>Tooltip for &quot;Reload using selected encoding&quot;</extracomment>
        <translation>Opna den gjeldande fila med den valde teiknkodinga.

Denne teiknkodinga vert då brukt i staden for standardteiknkodinga og eventuelle «%!TEX encoding»-linjer.</translation>
    </message>
    <message>
        <source>The file you are trying to reload has unsaved changes.

Do you want to discard your current changes, and reload the file from disk with the encoding %1?</source>
        <translation>Fila du prøver å opna på nytt har ulagra endringar.

Ønskjer du å forkasta endringane og lasta inn fila frå disk med teiknkodinga %1?</translation>
    </message>
    <message>
        <source>Write UTF-8 byte order mark</source>
        <translation>Skriv UTF-8-BOM</translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translation>standard</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>Ny fil frå mal</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>Vel mal for det nye dokumentet:</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>NewArgument</source>
        <translation>NyttArgument</translation>
    </message>
    <message>
        <source>Select program file</source>
        <translation>Vel programfil</translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation>Ugyldig program</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation>Fila «%1» er ikkje køyrbar</translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>Verktøyoppsett</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>Program:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Argument:</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>Vis PDF-fil etter kompilering</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Bla gjennom …</translation>
    </message>
</context>
</TS>
